@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -128,42 +128,21 @@ void
 command_save (GtkWidget *widget,
               gpointer   user_data)
 {
-  gchar *root = NULL, *tmp;
-  const gchar *file;
-  gint i = G_MAXINT, page_num;
-  MmaidWindow *mmaid;
+  gint page_num;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
-  file = orz_mdi_get_file (ORZ_MDI (mdi), page_num);
-  tmp = g_path_get_dirname (file);
-  root = g_strconcat (tmp, G_DIR_SEPARATOR_S, NULL);
-  g_free (tmp);
-  if (!orz_mdi_get_created (ORZ_MDI (mdi), page_num))
-    {
-      gchar *path;
-      gint leng;
-
-      path = g_filename_display_name (root);
-      leng = g_strlen (path);
-      for (i = mm_list_length (MM_LIST (mmaid->list)) - 1; i >= 0; i--)
-        {
-          const ID3Tag *id3tag;
-
-          id3tag = mm_list_get_nth (MM_LIST (mmaid->list), i);
-          if (g_strfilencmp (id3tag->file, path, leng))
-            break;
-        }
-      g_free (path);
-    }
-  if (i >= 0)
+  if (orz_mdi_get_created (ORZ_MDI (mdi), page_num))
     {
       command_saveas (widget, user_data);
     }
   else
     {
       gboolean result = TRUE;
+      const gchar *file;
+      MmaidWindow *mmaid;
 
+      file = orz_mdi_get_file (ORZ_MDI (mdi), page_num);
+      mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
       if (g_file_test (file, G_FILE_TEST_EXISTS))
         {
           gchar *utf8str;
@@ -180,15 +159,14 @@ command_save (GtkWidget *widget,
           result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
           gtk_widget_destroy (dialog);
         }
-      if (result &&  (mmaid->filetype == FILE_TYPE_DB
-            ? file_save_db (file, mmaid, root, mmaid->charset)
+      if (result && (mmaid->filetype == FILE_TYPE_DB
+            ? file_save_db (file, mmaid, mmaid->charset)
             : file_save_list (file, mmaid, mmaid->charset,
                 mmaid->playlist, mmaid->separator, mmaid->crlf, mmaid->header))
                  && (mmaid->filetype == FILE_TYPE_DB
                                     || mmaid->playlist != PLAYLIST_BASENAME))
         orz_mdi_set_edited (ORZ_MDI (mdi), page_num, FALSE);
     }
-  g_free (root);
 }
 
 
@@ -199,7 +177,6 @@ typedef struct _SaveDialog
   GtkWidget *frame_sep, *radio_slash, *radio_yen;
   GtkWidget *check_header;
   GtkWidget *combo_encoding, *radio_crlf, *radio_cr, *radio_lf;
-  GtkWidget *label_root, *combo_root;
 } SaveDialog;
 
 
@@ -219,8 +196,6 @@ command_save_toggled_radio_db (GtkWidget  *widget,
   gtk_widget_set_sensitive (savedlg->radio_cr, !active);
   gtk_widget_set_sensitive (savedlg->radio_lf, !active);
   gtk_widget_set_sensitive (savedlg->check_header, !active);
-  gtk_widget_set_sensitive (savedlg->label_root, active);
-  gtk_widget_set_sensitive (savedlg->combo_root, active);
 }
 
 
@@ -234,45 +209,6 @@ command_save_toggled_radio_basename (GtkWidget  *widget,
 }
 
 
-/* ja:コンボボックスが変更された */
-static void
-command_save_changed (GtkWidget *widget,
-                      GtkWidget *dialog)
-{
-  gchar *root, *utf8str;
-
-#if GTK_CHECK_VERSION(2,4,0)
-# if GTK_CHECK_VERSION(2,24,0)
-  utf8str = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (widget));
-# elif GTK_CHECK_VERSION(2,6,0)
-  utf8str = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
-# else /* not GTK_CHECK_VERSION(2,6,0) */
-  GtkTreeIter iter;
-
-  if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter))
-        gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (widget)),
-                                                    &iter, 0, &utf8str, -1);
-# endif /* not GTK_CHECK_VERSION(2,6,0) */
-  root = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
-  gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), root);
-  g_free (root);
-  g_free (utf8str);
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  gchar *file, *name, *root;
-
-  name = g_path_get_basename (gtk_file_selection_get_filename
-                                                (GTK_FILE_SELECTION (dialog)));
-  root = g_filename_from_utf8
-            (gtk_entry_get_text (GTK_ENTRY (widget)), -1, NULL, NULL, NULL);
-  file = g_strconcat (root, name, NULL);
-  gtk_file_selection_set_filename (GTK_FILE_SELECTION (dialog), file);
-  g_free (file);
-  g_free (name);
-  g_free (root);
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-}
-
-
 /* ja:コンボボックスが変更された */
 static void
 command_save_edited (GtkWidget *widget,
@@ -292,10 +228,9 @@ command_saveas (GtkWidget *widget,
                 gpointer   user_data)
 {
   gboolean header;
-  gchar *file, *root = NULL, *charset, *path, **ary, *title;
-  gint i, playlist, separator, crlf, page_num;
+  gchar *file, *charset, *title;
+  gint playlist, separator, crlf, page_num;
   guint filetype;
-  GList *gl, *glist = NULL;
   GtkStockItem stock_item;
   GtkWidget *dialog, *frame, *hbox, *vbox;
   GtkWidget *label_path, *label_sep, *label_encoding;
@@ -304,75 +239,6 @@ command_saveas (GtkWidget *widget,
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
   mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
-  /* ja:共通のルートを求める */
-  for (i = mm_list_length (MM_LIST (mmaid->list)) - 1; i >= 0; i--)
-    {
-      const ID3Tag *id3tag;
-
-      id3tag = mm_list_get_nth (MM_LIST (mmaid->list), i);
-      if (root)
-        {
-          gint j;
-
-          for (j = 0; root[j] != '\0'; j++)
-            if (root[j] != id3tag->file[j])
-              break;
-          root[j] = '\0';
-        }
-      else
-        {
-          root = g_strdup (id3tag->file);
-        }
-    }
-  path = g_strrchr (root, G_DIR_SEPARATOR);
-  if (!path)
-    {
-      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
-                            _("Root Directory Error"));
-      g_signal_connect (G_OBJECT (dialog), "key-press-event",
-                                    G_CALLBACK (misc_dialog_key_press), NULL);
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
-      return;
-    }
-  *path = '\0';
-#ifdef G_OS_WIN32
-  if (G_IS_DIR_SEPARATOR (root[0]) && G_IS_DIR_SEPARATOR (root[1]))
-    {
-      ary = g_strsplit (root + 2, G_DIR_SEPARATOR_S, 0);
-      path = g_strdup (G_DIR_SEPARATOR_S G_DIR_SEPARATOR_S);
-    }
-  else
-    {
-      ary = g_strsplit (root, G_DIR_SEPARATOR_S, 0);
-      path = NULL;
-    }
-#else /* not G_OS_WIN32 */
-  ary = g_strsplit (root, G_DIR_SEPARATOR_S, 0);
-  path = NULL;
-#endif /* not G_OS_WIN32 */
-  g_free (root);
-  root = NULL;
-  for (i = 0; ary[i]; i++)
-    {
-      path = path ? g_strconcat (path, ary[i], G_DIR_SEPARATOR_S, NULL)
-                  : g_strconcat (      ary[i], G_DIR_SEPARATOR_S, NULL);
-      glist = g_list_append (glist, path);
-    }
-  g_strfreev (ary);
-  if (save_path)
-    {
-      gchar *utf8str;
-
-      utf8str = g_filename_to_utf8 (save_path, -1, NULL, NULL, NULL);
-      if (g_strfilencmp (utf8str, path, g_strlen (utf8str)) == 0)
-        root = g_strconcat (save_path, G_DIR_SEPARATOR_S, NULL);
-      g_free (utf8str);
-    }
-  if (!root)
-    root = g_filename_from_utf8 (path, -1, NULL, NULL, NULL);
   /* ja:ダイアログ */
   gtk_stock_lookup (GTK_STOCK_SAVE_AS, &stock_item);
   title = misc_mnemonic_to_text (stock_item.label);
@@ -460,42 +326,6 @@ command_saveas (GtkWidget *widget,
                                                             mmaid->charset);
   g_signal_connect (G_OBJECT (savedlg.combo_encoding), "edited",
                                     G_CALLBACK (command_save_edited), dialog);
-  /* ja:コンボボックス */
-#if GTK_CHECK_VERSION(2,24,0)
-  savedlg.combo_root = gtk_combo_box_text_new ();
-  for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
-    {
-      gtk_combo_box_text_prepend_text (GTK_COMBO_BOX_TEXT (savedlg.combo_root),
-                                                                    gl->data);
-      if (g_strfilecmp (gl->data, root) == 0)
-        gtk_combo_box_set_active (GTK_COMBO_BOX (savedlg.combo_root), 0);
-    }
-  g_signal_connect (G_OBJECT (savedlg.combo_root), "changed",
-                                    G_CALLBACK (command_save_changed), dialog);
-#elif GTK_CHECK_VERSION(2,4,0)
-  savedlg.combo_root = gtk_combo_box_new_text ();
-  for (gl = g_list_first (glist); gl; gl = g_list_next (gl))
-    {
-      gtk_combo_box_prepend_text (GTK_COMBO_BOX (savedlg.combo_root),
-                                                                    gl->data);
-      if (g_strfilecmp (gl->data, root) == 0)
-        gtk_combo_box_set_active (GTK_COMBO_BOX (savedlg.combo_root), 0);
-    }
-  g_signal_connect (G_OBJECT (savedlg.combo_root), "changed",
-                                    G_CALLBACK (command_save_changed), dialog);
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  savedlg.combo_root = gtk_combo_new ();
-  gtk_combo_set_popdown_strings (GTK_COMBO (savedlg.combo_root), glist);
-  gtk_combo_set_value_in_list (GTK_COMBO (savedlg.combo_root), FALSE, FALSE);
-  gtk_combo_set_case_sensitive (GTK_COMBO (savedlg.combo_root), TRUE);
-  gtk_editable_set_editable
-                (GTK_EDITABLE (GTK_COMBO (savedlg.combo_root)->entry), FALSE);
-  gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (savedlg.combo_root)->entry), root);
-  g_signal_connect (G_OBJECT (GTK_COMBO (savedlg.combo_root)->entry),
-                        "changed", G_CALLBACK (command_save_changed), dialog);
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-  g_list_foreach (glist, (GFunc)g_free, NULL);
-  g_list_free (glist);
   /* ja:ラベル */
   label_path = gtk_label_new_with_mnemonic (_("_Path"));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_path),
@@ -505,14 +335,6 @@ command_saveas (GtkWidget *widget,
   label_encoding = gtk_label_new_with_mnemonic (_("Character _Encoding"));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_encoding),
                                                     savedlg.combo_encoding);
-  savedlg.label_root = gtk_label_new_with_mnemonic (_("_Root"));
-#if GTK_CHECK_VERSION(2,4,0)
-  gtk_label_set_mnemonic_widget (GTK_LABEL (savedlg.label_root),
-                                                        savedlg.combo_root);
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  gtk_label_set_mnemonic_widget (GTK_LABEL (savedlg.label_root),
-                                        GTK_COMBO (savedlg.combo_root)->entry);
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:フレームとボックス */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
@@ -548,10 +370,6 @@ command_saveas (GtkWidget *widget,
   gtk_box_pack_start (GTK_BOX (hbox), savedlg.radio_lf, FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (frame), hbox);
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
-  hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_start (GTK_BOX (hbox), savedlg.label_root, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (hbox), savedlg.combo_root, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
   /* ja:表示 */
   command_save_toggled_radio_db (savedlg.radio_db, &savedlg);
   gtk_widget_show_all (vbox);
@@ -567,23 +385,13 @@ command_saveas (GtkWidget *widget,
 # endif /* not GTK_CHECK_VERSION(2,6,0) */
 
       file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-# if GTK_CHECK_VERSION(2,24,0)
-      root = gtk_combo_box_text_get_active_text
-                                    (GTK_COMBO_BOX_TEXT (savedlg.combo_root));
-# elif GTK_CHECK_VERSION(2,6,0)
-      root = gtk_combo_box_get_active_text
-                                        (GTK_COMBO_BOX (savedlg.combo_root));
-# else /* not GTK_CHECK_VERSION(2,6,0) */
-      if (gtk_combo_box_get_active_iter
-                                (GTK_COMBO_BOX (savedlg.combo_root), &iter))
-        gtk_tree_model_get (gtk_combo_box_get_model
-                    (GTK_COMBO_BOX (savedlg.combo_root)), &iter, 0, &root, -1);
-# endif /* not GTK_CHECK_VERSION(2,6,0) */
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_box_pack_end (GTK_BOX (GTK_FILE_SELECTION (dialog)->main_vbox),
                                                         vbox, FALSE, FALSE, 0);
   if (save_path)
     {
+      gchar *path;
+
       path = g_strconcat (save_path, G_SEARCHPATH_SEPARATOR_S, NULL);
       gtk_file_selection_set_filename (GTK_FILE_SELECTION (dialog), path);
       g_free (path);
@@ -593,8 +401,6 @@ command_saveas (GtkWidget *widget,
     {
       file = g_strdup (gtk_file_selection_get_filename
                                                 (GTK_FILE_SELECTION (dialog)));
-      root = g_strdup (gtk_entry_get_text
-                        (GTK_ENTRY (GTK_COMBO (savedlg.combo_root)->entry)));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
       charset = orz_charset_get_charset (ORZ_CHARSET (savedlg.combo_encoding));
       filetype = gtk_toggle_button_get_active
@@ -622,7 +428,7 @@ command_saveas (GtkWidget *widget,
     }
   else
     {
-      file = root = charset = NULL;
+      file = charset = NULL;
       filetype = FILE_TYPE_DB;
       playlist = PLAYLIST_RELATIVE;
       separator = G_DIR_SEPARATOR;
@@ -634,7 +440,7 @@ command_saveas (GtkWidget *widget,
       header = TRUE;
     }
   gtk_widget_destroy (dialog);
-  if (file && root && charset)
+  if (file && charset)
     {
       gboolean result = TRUE;
 
@@ -654,10 +460,12 @@ command_saveas (GtkWidget *widget,
           gtk_widget_destroy (dialog);
         }
       if (result && (filetype == FILE_TYPE_DB
-                                    ? file_save_db (file, mmaid, root, charset)
+                                    ? file_save_db (file, mmaid, charset)
                                     : file_save_list (file, mmaid, charset,
                                         playlist, separator, crlf, header)))
         {
+          gchar *path;
+
           g_free (save_path);
           path = fileio_get_full_path (file);
           save_path = g_path_get_dirname (path);
@@ -684,7 +492,6 @@ command_saveas (GtkWidget *widget,
         }
     }
   g_free (file);
-  g_free (root);
   g_free (charset);
 }
 
