@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -272,7 +272,7 @@ edit_dialog (MmaidWindow *mmaid)
   combo_artist = gtk_combo_box_text_new_with_entry ();
   combo_album = gtk_combo_box_text_new_with_entry ();
   combo_comment = gtk_combo_box_text_new_with_entry ();
-  combo_genre = gtk_combo_box_new_with_entry ();
+  combo_genre = gtk_combo_box_text_new_with_entry ();
 # else /* not GTK_CHECK_VERSION(2,24,0) */
   combo_title = gtk_combo_box_entry_new_text ();
   combo_artist = gtk_combo_box_entry_new_text ();
