@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -420,17 +420,17 @@ file_open_db (const gchar *file,
     || (entries = GINT32_FROM_LE (*(gint32 *)(header + 0x0040))) > 10240)
     entries = 0;/* ja:ヘッタにエラーがある */
   /* ja:ヘッタのPaddingをチェック */
-  if (entries)
-    for (i = 0x0042; i <= 0x007F; i++)
-      if (header[i])
+  if (entries > 0)
+    for (i = 0x0042; i <= 0x007f; i++)
+      if (header[i] > 0)
         {
           entries = 0;
           break;
         }
   /* ja:ヘッタのオフセットのない部分をチェック */
-  if (entries)
+  if (entries > 0)
     for (i = entries * sizeof (guint32) + 0x0080; i <= 0xa07f; i++)
-      if (header[i])
+      if (header[i] > 0)
         {
           entries = 0;
           break;
@@ -463,7 +463,7 @@ file_open_db (const gchar *file,
           offset += mi_r[i].len[j];
         }
     }
-  if (entries)
+  if (entries > 0)
     entries = i;
   if (fio)
     fileio_close (fio);
@@ -949,15 +949,14 @@ file_save_id3tag (const gchar  *file,
 /*  ja:dbファイルを保存する
        file,ファイル名
       mmaid,ウインドウ情報
-       root,ルート
     charset,キャラクターセット
         RET,TRUE:正常終了,FALSE:エラー                                      */
 gboolean
 file_save_db (const gchar *file,
               MmaidWindow *mmaid,
-              const gchar *root,
               const gchar *charset)
 {
+  gchar *root, *tmp;
   guint8 *buf;
   gint i, count, length;
   goffset offset = 0xa0c0;
@@ -970,6 +969,11 @@ file_save_db (const gchar *file,
   gtk_grab_add (dialog);
   /* ja:変数 */
   count = MIN (mm_list_length (MM_LIST (mmaid->list)), 10240);
+  root = fileio_get_full_path (file);
+  tmp = g_path_get_dirname (root);
+  g_free (root);
+  root = g_strconcat (tmp, G_DIR_SEPARATOR_S, NULL);
+  g_free (tmp);
   length = g_strlen (root);
   buf = g_malloc0 ((gsize)offset);
   g_memmove (buf,          irivdb_header0, sizeof (irivdb_header0));
@@ -978,28 +982,43 @@ file_save_db (const gchar *file,
   /* ja:タグ */
   for (i = 0; userbreak && i < count; i++)
     {
-      gchar *file = NULL, *title, *artist, *album, *genre, **ary, *tmp;
-      gint j;
+      gchar *file = NULL, *title, *artist, *album, *genre;
       const ID3Tag *id3tag;
 
       while (gtk_events_pending ())
         gtk_main_iteration ();
       id3tag = mm_list_get_nth (MM_LIST (mmaid->list), i);
-      ary = g_strsplit (id3tag->file + length, G_DIR_SEPARATOR_S, 0);
-      for (j = 0; ary[j]; j++)
+      if (g_strfilencmp (id3tag->file, root, length) == 0)
         {
-          tmp = g_convert (ary[j], -1, charset, "UTF-8", NULL, NULL, NULL);
-          if (!tmp)
+          gchar **ary;
+          gint j;
+
+          ary = g_strsplit (id3tag->file + length, G_DIR_SEPARATOR_S, 0);
+          for (j = 0; ary[j]; j++)
             {
-              g_free (file);
-              file = NULL;
-              break;
+              gchar *str;
+
+              str = g_convert (ary[j], -1, charset, "UTF-8", NULL, NULL, NULL);
+              if (!str)
+                {
+                  g_free (file);
+                  file = NULL;
+                  break;
+                }
+              if (file)
+                {
+                  tmp = g_strconcat (file, "\\", str, NULL);
+                  g_free (file);
+                }
+              else
+                {
+                  tmp = g_strconcat ("\\", str, NULL);
+                }
+              g_free (str);
+              file = tmp;
             }
-          file = file ? g_strconcat (file, "\\", tmp, NULL)
-                      : g_strconcat (      "\\", tmp, NULL);
-          g_free (tmp);
+          g_strfreev (ary);
         }
-      g_strfreev (ary);
       title  = id3tag->title  ? g_convert (id3tag->title,  -1,
                                         charset, "UTF-8", NULL, NULL, NULL)
                               : g_malloc0 (sizeof (gchar));
@@ -1017,6 +1036,7 @@ file_save_db (const gchar *file,
           guint8 *p;
           guint16 len[5];
           gsize leng[5], size = sizeof (len);
+          gint j;
 
           leng[0] = g_strlen (file)   + 1;
           leng[1] = g_strlen (title)  + 1;
@@ -1096,6 +1116,7 @@ file_save_db (const gchar *file,
       g_free (album);
       g_free (genre);
     }
+  g_free (root);
   fio = userbreak ? fileio_open (file,
                         FILEIO_ACCESS_READ | FILEIO_ACCESS_WRITE,
                         FILEIO_SHARE_READ, FILEIO_MODE_CREATE_ALWAYS) : NULL;
@@ -1160,8 +1181,8 @@ file_save_list (const gchar    *file,
                                 FILEIO_SHARE_READ, FILEIO_MODE_CREATE_ALWAYS);
   if (fio)
     {
-      char *root;
-      const char *sep, *newline;
+      gchar *root;
+      const gchar *sep, *newline;
       gint i, count;
       GtkWidget *dialog;
 
