@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -109,13 +109,11 @@ file_save_id3tag (const gchar  *file,
 /*  ja:dbファイルを保存する
        file,ファイル名
       mmaid,ウインドウ情報
-       root,ルート
     charset,キャラクターセット
         RET,TRUE:正常終了,FALSE:エラー                                      */
 gboolean
 file_save_db (const gchar *file,
               MmaidWindow *mmaid,
-              const gchar *root,
               const gchar *charset);
 
 
