@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -129,8 +129,8 @@ mm_dialog_init (MmDialog *dialog)
                                 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_container_set_border_width (GTK_CONTAINER (scroll), SPACING);
   /* ja:フレームとボックス */
-  gtk_container_add (GTK_CONTAINER
-                (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), scroll);
+  gtk_box_pack_end (GTK_BOX (gtk_dialog_get_content_area
+                                (GTK_DIALOG (dialog))), scroll, TRUE, TRUE, 0);
 
   /* ja:表示 */
   gtk_widget_show_all (scroll);
