@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2009 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 #include "mm_list.h"
 #include "misc/charuty.h"
 #include "misc/misc.h"
-#include <gdk/gdkkeysyms.h>
 
 
 enum
@@ -46,16 +45,64 @@ static gint mm_list_signals[LAST_SIGNAL] = {0};
 *                                                                             *
 ******************************************************************************/
 G_DEFINE_TYPE (MmList, mm_list, GTK_TYPE_TREE_VIEW);
+#if GTK_CHECK_VERSION(3,0,0)
+static void mm_list_destroy (GtkWidget *widget);
+#else /* not GTK_CHECK_VERSION(3,0,0) */
 static void mm_list_destroy (GtkObject *object);
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
+
+
+static void
+mm_list_marshal_VOID__INT_INT (GClosure     *closure,
+                               GValue       *return_value G_GNUC_UNUSED,
+                               guint         n_param_values,
+                               const GValue *param_values,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
+                               gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
+                                              gint         arg_1,
+                                              gint         arg_2,
+                                              gpointer     data2);
+  register GMarshalFunc_VOID__INT_INT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__INT_INT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_value_get_int (param_values + 1),
+            g_value_get_int (param_values + 2),
+            data2);
+}
 
 
 static void
 mm_list_class_init (MmListClass *klass)
 {
+#if GTK_CHECK_VERSION(3,0,0)
+  GtkWidgetClass *widget_class;
+
+  widget_class = GTK_WIDGET_CLASS (klass);
+  widget_class->destroy = mm_list_destroy;
+#else /* not GTK_CHECK_VERSION(3,0,0) */
   GtkObjectClass *object_class;
 
   object_class = GTK_OBJECT_CLASS (klass);
   object_class->destroy = mm_list_destroy;
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
 
   klass->changed  = NULL;
   klass->deleted  = NULL;
@@ -87,7 +134,7 @@ mm_list_class_init (MmListClass *klass)
                                 G_SIGNAL_RUN_FIRST | G_SIGNAL_DETAILED,
                                 G_STRUCT_OFFSET (MmListClass, edited),
                                 NULL, NULL,
-                                gtk_marshal_VOID__INT_INT,
+                                mm_list_marshal_VOID__INT_INT,
                                 G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
   mm_list_signals[INSERTED_SIGNAL]
                 = g_signal_new ("inserted",
@@ -103,7 +150,7 @@ mm_list_class_init (MmListClass *klass)
                                 G_SIGNAL_RUN_FIRST | G_SIGNAL_DETAILED,
                                 G_STRUCT_OFFSET (MmListClass, moved),
                                 NULL, NULL,
-                                gtk_marshal_VOID__INT_INT,
+                                mm_list_marshal_VOID__INT_INT,
                                 G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
   mm_list_signals[SORTED_SIGNAL]
                 = g_signal_new ("sorted",
@@ -125,6 +172,18 @@ mm_list_class_init (MmListClass *klass)
 
 
 /* ja:ツリービュー削除 */
+#if GTK_CHECK_VERSION(3,0,0)
+static void
+mm_list_destroy (GtkWidget *widget)
+{
+  if (MM_LIST (widget)->signal)
+    {
+      MM_LIST (widget)->signal = FALSE;
+      mm_list_delete_all (MM_LIST (widget));
+    }
+  GTK_WIDGET_CLASS (mm_list_parent_class)->destroy (widget);
+}
+#else /* not GTK_CHECK_VERSION(3,0,0) */
 static void
 mm_list_destroy (GtkObject *object)
 {
@@ -135,6 +194,7 @@ mm_list_destroy (GtkObject *object)
     }
   GTK_OBJECT_CLASS (mm_list_parent_class)->destroy (object);
 }
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
 
 
 /* ja:選択が変化した */
@@ -316,7 +376,8 @@ mm_list_init (MmList *list)
   static gchar *title[] = {N_("File"),  N_("Title"), N_("Artist"),
                            N_("Album"), N_("Year"),  N_("Comment"),
                            N_("Track"), N_("Genre"), N_("Character Encoding")};
-  GtkTargetEntry dnd_entries[1] = {{"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET | GTK_TARGET_SAME_WIDGET, TARGET_MMAID_ID3TAG}};
+  GtkTargetEntry dnd_entries[1] = {{"GTK_TREE_MODEL_ROW",
+                                GTK_TARGET_SAME_WIDGET, TARGET_MMAID_ID3TAG}};
 
   list->editable       = FALSE;
   list->editable_file  = FALSE;
@@ -1044,8 +1105,11 @@ mm_list_set_cursor (MmList     *list,
     {
       gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &path, NULL);
     }
-  gtk_tree_view_set_cursor (GTK_TREE_VIEW (list), path, column, FALSE);
-  gtk_tree_path_free (path);
+  if (path)
+    {
+      gtk_tree_view_set_cursor (GTK_TREE_VIEW (list), path, column, FALSE);
+      gtk_tree_path_free (path);
+    }
 }
 
 
