@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -108,12 +108,11 @@ reload_dialog (MmaidWindow *mmaid,
                                 G_CALLBACK (reload_dialog_edited), dialog);
   g_object_set_data (G_OBJECT (dialog), "user_data", charset);
   /* ja:フレームとボックス */
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   if (text)
     gtk_box_pack_start (GTK_BOX (vbox), gtk_label_new (text), FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), charset, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
 
   /* ja:表示 */
   gtk_widget_show_all (vbox);
