@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -264,9 +264,9 @@ root_dialog (MmaidWindow *mmaid)
               glist = g_list_insert_sorted (glist, g_strdup (path),
                                             (GCompareFunc)g_ascii_strcasecmp);
 #else /* not G_OS_WIN32 */
-            if (!g_list_find_custom (glist, path, (GCompareFunc)strcmp))
+            if (!g_list_find_custom (glist, path, (GCompareFunc)g_strcmp))
               glist = g_list_insert_sorted (glist, g_strdup (path),
-                                                (GCompareFunc)strcmp);
+                                                (GCompareFunc)g_strcmp);
 #endif /* not G_OS_WIN32 */
           }
         g_strfreev (dir);
@@ -305,7 +305,7 @@ root_dialog (MmaidWindow *mmaid)
                                     G_CALLBACK (root_dialog_activate), &rtdlg);
   g_signal_connect (G_OBJECT (GTK_COMBO (rtdlg.combo)->entry), "changed",
                                     G_CALLBACK (root_dialog_changed), &rtdlg);
-  g_list_find_custom (glist, (GFunc)g_free, NULL);
+  g_list_foreach (glist, (GFunc)g_free, NULL);
   g_list_free (glist);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:エントリー */
